==> qtjambi-xml-5.15.6-sources.jar: io/qt/xml/QXmlErrorHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report errors in XML data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html">QXmlErrorHandler</a></p>
 */
@Deprecated
public interface QXmlErrorHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlErrorHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlErrorHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlErrorHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean error(io.qt.xml.QXmlParseException exception){
                return error_native_cref_QXmlParseException(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(exception));
            }
            private native static boolean error_native_cref_QXmlParseException(long __this__nativeId, long exception);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean fatalError(io.qt.xml.QXmlParseException exception){
                return fatalError_native_cref_QXmlParseException(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(exception));
            }
            private native static boolean fatalError_native_cref_QXmlParseException(long __this__nativeId, long exception);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean warning(io.qt.xml.QXmlParseException exception){
                return warning_native_cref_QXmlParseException(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(exception));
            }
            private native static boolean warning_native_cref_QXmlParseException(long __this__nativeId, long exception);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlErrorHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#error">QXmlErrorHandler::error(QXmlParseException)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean error(io.qt.xml.QXmlParseException exception);
        
        private native static boolean error_native_cref_QXmlParseException(long __this__nativeId, long exception);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#errorString">QXmlErrorHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#fatalError">QXmlErrorHandler::fatalError(QXmlParseException)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean fatalError(io.qt.xml.QXmlParseException exception);
        
        private native static boolean fatalError_native_cref_QXmlParseException(long __this__nativeId, long exception);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#warning">QXmlErrorHandler::warning(QXmlParseException)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean warning(io.qt.xml.QXmlParseException exception);
        
        private native static boolean warning_native_cref_QXmlParseException(long __this__nativeId, long exception);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#error">QXmlErrorHandler::error(QXmlParseException)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean error(io.qt.xml.QXmlParseException exception);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#errorString">QXmlErrorHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#fatalError">QXmlErrorHandler::fatalError(QXmlParseException)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean fatalError(io.qt.xml.QXmlParseException exception);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#warning">QXmlErrorHandler::warning(QXmlParseException)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean warning(io.qt.xml.QXmlParseException exception);
    
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QXmlErrorHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report errors in XML data</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html">QXmlErrorHandler</a></p>
 */
@Deprecated
public interface QXmlErrorHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlErrorHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlErrorHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlErrorHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean error(io.qt.xml.QXmlParseException exception){
                return error_native_cref_QXmlParseException(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(exception));
            }
            private native static boolean error_native_cref_QXmlParseException(long __this__nativeId, long exception);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean fatalError(io.qt.xml.QXmlParseException exception){
                return fatalError_native_cref_QXmlParseException(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(exception));
            }
            private native static boolean fatalError_native_cref_QXmlParseException(long __this__nativeId, long exception);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean warning(io.qt.xml.QXmlParseException exception){
                return warning_native_cref_QXmlParseException(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(exception));
            }
            private native static boolean warning_native_cref_QXmlParseException(long __this__nativeId, long exception);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlErrorHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#error">QXmlErrorHandler::error(QXmlParseException)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean error(io.qt.xml.QXmlParseException exception);
        
        private native static boolean error_native_cref_QXmlParseException(long __this__nativeId, long exception);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#errorString">QXmlErrorHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#fatalError">QXmlErrorHandler::fatalError(QXmlParseException)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean fatalError(io.qt.xml.QXmlParseException exception);
        
        private native static boolean fatalError_native_cref_QXmlParseException(long __this__nativeId, long exception);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#warning">QXmlErrorHandler::warning(QXmlParseException)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean warning(io.qt.xml.QXmlParseException exception);
        
        private native static boolean warning_native_cref_QXmlParseException(long __this__nativeId, long exception);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#error">QXmlErrorHandler::error(QXmlParseException)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean error(io.qt.xml.QXmlParseException exception);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#errorString">QXmlErrorHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#fatalError">QXmlErrorHandler::fatalError(QXmlParseException)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean fatalError(io.qt.xml.QXmlParseException exception);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlerrorhandler.html#warning">QXmlErrorHandler::warning(QXmlParseException)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean warning(io.qt.xml.QXmlParseException exception);
    
}
